@@ -507,17 +507,15 @@ struct _xmlSecCryptoDLFunctions {
 };
 
 /**
- * ATTRIBUTE_UNUSED:
+ * XMLSEC_ATTRIBUTE_UNUSED:
  *
- * Macro used to signal to GCC unused function parameters
+ * Macro used to signal unused function parameters
  */
-#ifdef __GNUC__
-#ifndef ATTRIBUTE_UNUSED
-#define ATTRIBUTE_UNUSED
-#endif
-#else
-#define ATTRIBUTE_UNUSED
-#endif
+#if defined(__GNUC__) || defined(__clang__)
+#define XMLSEC_ATTRIBUTE_UNUSED __attribute__((unused))
+#else /* defined(__GNUC__) || defined(__clang__) */
+#define XMLSEC_ATTRIBUTE_UNUSED
+#endif /* defined(__GNUC__) || defined(__clang__) */
 
 /**
  * UNREFERENCED_PARAMETER:
